@@ -1,6 +1,14 @@
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+
 from .metrics import mr_score, mrr_score, hits_at_n_score
 from .protocol import add_reverse, get_triplets_set, Base, TrainEval_By_Triplet
 from .protocol import TrainEval_For_Trans, TrainEval_By_Pair
 
+from .Trainer import Trainer
+from .Tester import Tester
+
 __all__ = ['mr_score', 'mrr_score', 'hits_at_n_score', 'add_reverse', 'get_triplets_set', 
-           'Base', 'TrainEval_By_Triplet', 'TrainEval_For_Trans', 'TrainEval_By_Pair']
+           'Base', 'TrainEval_By_Triplet', 'TrainEval_For_Trans', 'TrainEval_By_Pair',
+           'Trainer', 'Tester']
